# Jupyter Console

A terminal-based console frontend for Jupter kernels.
This code is based on the single-process IPython terminal.

Install:

    pip install jupyter-console

Start:

    jupyter console

Help:

    jupyter console -h

